@@ -1,4 +1,6 @@
 import requests
+from stl_sdk.exceptions import CoreHttpError
+from requests.exceptions import HTTPError
 
 
 class CoralClient:
@@ -10,7 +12,7 @@ class CoralClient:
     """
 
     def __init__(self, coral_url, api_key, atlantis_client_id):
-        self.coral_url = coral_url
+        self.coral_url = coral_url.strip('/')
         self.api_key = api_key
         self.atlantis_client_id = atlantis_client_id
 
@@ -43,15 +45,18 @@ class CoralClient:
         :return: Objeto do arquivo
         :rtype: dict
         """
-        response = requests.get(
-                '{}/api/file'.format(self.coral_url),
-                headers=self._get_headers(bucket, region=region),
-                params={
-                    'key': key
-                }
-            )
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.get(
+                    '{}/api/file'.format(self.coral_url),
+                    headers=self._get_headers(bucket, region=region),
+                    params={
+                        'key': key
+                    }
+                )
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise CoralClientHTTPError(error) from error
 
 
 class CoralSyncClient(CoralClient):
@@ -91,19 +96,22 @@ class CoralSyncClient(CoralClient):
         :return: Objeto do arquivo persistido
         :rtype: dict
         """
-        response = requests.post(
-                '{}/api/sync'.format(self.coral_url),
-                headers=self._get_headers(bucket),
-                params={
-                    'key': key
-                }, json={
-                    'last_modified': last_modified,
-                    'size': size,
-                    'metadata': metadata,
-                }
-            )
-        response.raise_for_status()
-        return response.json()
+        try:
+            response = requests.post(
+                    '{}/api/sync'.format(self.coral_url),
+                    headers=self._get_headers(bucket),
+                    params={
+                        'key': key
+                    }, json={
+                        'last_modified': last_modified,
+                        'size': size,
+                        'metadata': metadata,
+                    }
+                )
+            response.raise_for_status()
+            return response.json()
+        except HTTPError as error:
+            raise CoralClientHTTPError(error) from error
 
     def delete_file(self, bucket, key):
         """Remove um arquivo do banco do Coral.
@@ -124,12 +132,19 @@ class CoralSyncClient(CoralClient):
         :return: Código da resposta (204 para successo)
         :rtype: int
         """
-        response = requests.delete(
-                '{}/api/sync'.format(self.coral_url),
-                headers=self._get_headers(bucket),
-                params={
-                    'key': key
-                }
-            )
-        response.raise_for_status()
-        return response.status_code
+        try:
+            response = requests.delete(
+                    '{}/api/sync'.format(self.coral_url),
+                    headers=self._get_headers(bucket),
+                    params={
+                        'key': key
+                    }
+                )
+            response.raise_for_status()
+            return response.status_code
+        except HTTPError as error:
+            raise CoralClientHTTPError(error) from error
+
+
+class CoralClientHTTPError(CoreHttpError):
+    pass
