@@ -8,3 +8,7 @@ class CoreHttpError(HTTPError):
 
     def __str__(self):
         return self.message
+
+
+class InvalidInitParameters(RuntimeError):
+    pass
